CLASS = 'cl'
PACKAGE = 'Module'
METHOD = 'clm'
FUNCTION = 'func'
ATTRIBUTE = 'Attribute'
CONSTANT = 'clconst'
